from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.api_value_composition_array import ApiValueCompositionArray
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputCalculationResultPhaseComposition")


@attr.s(auto_attribs=True)
class ApiOutputCalculationResultPhaseComposition:
    """Holds composition information for a phase"""

    composition_units: Union[Unset, None, str] = UNSET
    molar_mass_units: Union[Unset, None, str] = UNSET
    composition: Union[Unset, ApiValueCompositionArray] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        composition_units = self.composition_units
        molar_mass_units = self.molar_mass_units
        composition: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.composition, Unset):
            composition = self.composition.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if composition_units is not UNSET:
            field_dict["compositionUnits"] = composition_units
        if molar_mass_units is not UNSET:
            field_dict["molarMassUnits"] = molar_mass_units
        if composition is not UNSET:
            field_dict["composition"] = composition

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        composition_units = d.pop("compositionUnits", UNSET)

        molar_mass_units = d.pop("molarMassUnits", UNSET)

        _composition = d.pop("composition", UNSET)
        composition: Union[Unset, ApiValueCompositionArray]
        if isinstance(_composition, Unset):
            composition = UNSET
        else:
            composition = ApiValueCompositionArray.from_dict(_composition)

        api_output_calculation_result_phase_composition = cls(
            composition_units=composition_units,
            molar_mass_units=molar_mass_units,
            composition=composition,
        )

        return api_output_calculation_result_phase_composition



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.calculation_composition import CalculationComposition
from ..models.api_fluid import ApiFluid
from ..types import UNSET, Unset

T = TypeVar("T", bound="SlePointCalculationInput")


@attr.s(auto_attribs=True)
class SlePointCalculationInput:
    """Input for SLE point calculation"""

    access_key: str
    components: List[CalculationComposition]
    pointtype: str # Type of calculation. Allowed values are: Fixed Pressure, Fixed Temperature/Pressure
    units: str
    fluidid: Union[Unset, str] = UNSET #Id of fluid on webserver. Must be defined if no fluid given in fluid argument
    fluid: Union[Unset, ApiFluid] = UNSET #Fluid information
    temperature: Union[Unset, float] = UNSET
    pressure: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        access_key = self.access_key
        components = []
        for components_item_data in self.components:
            components_item = components_item_data.to_dict()

            components.append(components_item)

        pointtype = self.pointtype

        units = self.units

        temperature = self.temperature
        pressure = self.pressure

        fluidid: Union[Unset, str] = UNSET
        if not isinstance(self.fluidid, Unset):
            fluid = self.fluidid

        fluid: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fluid, Unset):
            fluid = self.fluid.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "accessKey": access_key,
                "components": components,
                "pointType": pointtype,
            }
        )
        if units is not UNSET:
            field_dict["units"] = units
        if fluidid is not UNSET:
            field_dict["fluidId"] = fluidid
        if fluid is not UNSET:
            field_dict["fluid"] = fluid
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if pressure is not UNSET:
            field_dict["pressure"] = pressure

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        access_key = d.pop("accessKey")

        components = []
        _components = d.pop("components")
        for components_item_data in _components:
            components_item = CalculationComposition.from_dict(components_item_data)

            components.append(components_item)

        _fluidid = d.pop("fluidId", UNSET)
        fluidid: Union[Unset, str]
        if isinstance(_fluidid, Unset):
            fluidid = UNSET
        else:
            fluidid = _fluidid

        _fluid = d.pop("fluid", UNSET)
        fluid: Union[Unset, ApiFluid]
        if isinstance(_fluid, Unset):
            fluid = UNSET
        else:
            fluid = ApiFluid.from_dict(_fluid)
        pointtype = d.pop("pointType")

        units = d.pop("units", UNSET)

        temperature = d.pop("temperature", UNSET)

        pressure = d.pop("pressure", UNSET)

        sle_point_calculation_input = cls(
            access_key=access_key,
            components=components,
            fluidid=fluidid,
            fluid=fluid,
            pointtype=pointtype,
            units=units,
            temperature=temperature,
            pressure=pressure,
        )

        return sle_point_calculation_input



from pickle import NONE
import pytest
from equia.models import CalculationComposition, ProblemDetails 
from equia.equia_client import EquiaClient
from equia.demofluids.demofluid1_nHexane_Ethylene_HDPE7 import demofluid1_nHexane_Ethylene_HDPE7
from utility.shared_settings import sharedsettings

@pytest.mark.asyncio
async def test_call_cloudpoint():
    client = EquiaClient(sharedsettings.url, sharedsettings.access_key)

    input = client.get_cloud_point_input()
    input.fluid = demofluid1_nHexane_Ethylene_HDPE7()
    input.pressure = 30
    input.pointtype = "Fixed Pressure"
    input.components = [
        CalculationComposition(mass=0.78),
        CalculationComposition(mass=0.02),
        CalculationComposition(mass=0.20)
    ]
    input.units = "C(In,Massfraction);C(Out,Massfraction);T(In,Kelvin);T(Out,Kelvin);P(In,Bar);P(Out,Bar);H(In,kJ/Kg);H(Out,kJ/Kg);S(In,kJ/(Kg Kelvin));S(Out,kJ/(Kg Kelvin));Cp(In,kJ/(Kg Kelvin));Cp(Out,kJ/(Kg Kelvin));Viscosity(In,centiPoise);Viscosity(Out,centiPoise);Surfacetension(In,N/m);Surfacetension(Out,N/m)"

    result: ProblemDetails = await client.call_cloud_point_async(input)

    await client.cleanup()

    #assert result.status == 400
    assert result.success == True
    assert len(result.point.phases) == 2



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.api_value_floating_with_units import ApiValueFloatingWithUnits
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputEosProperetiesTPnResultIdeal")


@attr.s(auto_attribs=True)
class ApiOutputEosProperetiesTPnResultIdeal:
    """Holds ideal values"""

    volume: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    gibbs_energy: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    internal_energy: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    helmholtz_energy: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    cv: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    cp: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    enthalpy: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    entropy: Union[Unset, ApiValueFloatingWithUnits] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        gibbs_energy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.gibbs_energy, Unset):
            gibbs_energy = self.gibbs_energy.to_dict()

        internal_energy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.internal_energy, Unset):
            internal_energy = self.internal_energy.to_dict()

        helmholtz_energy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.helmholtz_energy, Unset):
            helmholtz_energy = self.helmholtz_energy.to_dict()

        cv: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.cv, Unset):
            cv = self.cv.to_dict()

        cp: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.cp, Unset):
            cp = self.cp.to_dict()

        enthalpy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.enthalpy, Unset):
            enthalpy = self.enthalpy.to_dict()

        entropy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.entropy, Unset):
            entropy = self.entropy.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if volume is not UNSET:
            field_dict["volume"] = volume
        if gibbs_energy is not UNSET:
            field_dict["gibbsEnergy"] = gibbs_energy
        if internal_energy is not UNSET:
            field_dict["internalEnergy"] = internal_energy
        if helmholtz_energy is not UNSET:
            field_dict["helmholtzEnergy"] = helmholtz_energy
        if cv is not UNSET:
            field_dict["cv"] = cv
        if cp is not UNSET:
            field_dict["cp"] = cp
        if enthalpy is not UNSET:
            field_dict["enthalpy"] = enthalpy
        if entropy is not UNSET:
            field_dict["entropy"] = entropy

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = ApiValueFloatingWithUnits.from_dict(_volume)

        _gibbs_energy = d.pop("gibbsEnergy", UNSET)
        gibbs_energy: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_gibbs_energy, Unset):
            gibbs_energy = UNSET
        else:
            gibbs_energy = ApiValueFloatingWithUnits.from_dict(_gibbs_energy)

        _internal_energy = d.pop("internalEnergy", UNSET)
        internal_energy: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_internal_energy, Unset):
            internal_energy = UNSET
        else:
            internal_energy = ApiValueFloatingWithUnits.from_dict(_internal_energy)

        _helmholtz_energy = d.pop("helmholtzEnergy", UNSET)
        helmholtz_energy: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_helmholtz_energy, Unset):
            helmholtz_energy = UNSET
        else:
            helmholtz_energy = ApiValueFloatingWithUnits.from_dict(_helmholtz_energy)

        _cv = d.pop("cv", UNSET)
        cv: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_cv, Unset):
            cv = UNSET
        else:
            cv = ApiValueFloatingWithUnits.from_dict(_cv)

        _cp = d.pop("cp", UNSET)
        cp: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_cp, Unset):
            cp = UNSET
        else:
            cp = ApiValueFloatingWithUnits.from_dict(_cp)

        _enthalpy = d.pop("enthalpy", UNSET)
        enthalpy: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_enthalpy, Unset):
            enthalpy = UNSET
        else:
            enthalpy = ApiValueFloatingWithUnits.from_dict(_enthalpy)

        _entropy = d.pop("entropy", UNSET)
        entropy: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_entropy, Unset):
            entropy = UNSET
        else:
            entropy = ApiValueFloatingWithUnits.from_dict(_entropy)

        api_output_eospropertiestpn_ideal = cls(
            volume=volume,
            gibbs_energy=gibbs_energy,
            internal_energy=internal_energy,
            helmholtz_energy=helmholtz_energy,
            cv=cv,
            cp=cp,
            enthalpy=enthalpy,
            entropy=entropy,
        )

        return api_output_eospropertiestpn_ideal



from equia.models import ApiFluid, ApiFluidStandardComponent,ApiFluidPolymerComponent,ApiFluidComponentBlock,ApiFluidPseudoComponent, ApiFluidKij

def demofluid1_nHexane_Ethylene_HDPE7() -> ApiFluid:
    '''Predefined fluid with 2 solvents and a HDPE polymer with 7 pseudo components'''   
    fluid = ApiFluid()
    fluid.name = "n-Hexane + Ethylene + HDPE(7)"
    fluid.eos = "PC-SAFT"
    fluid.solvent_cp = "DIPPR"
    fluid.polymer_cp = "Polynomial"

    fluid.standards = [
      ApiFluidStandardComponent(name="n-Hexane",is_alkane=True, molar_mass=86.17536,         
        acentric_factor = 0.301261,
        critical_pressure = 30.25,
        critical_temperature = 507.6,
        pc_saftdm = 0.03548,
        pc_saft_sigma_0 = 3.7983,
        pc_saft_epsilon = 236.77,
        ideal_gas_enthalpy_of_formation = -1937.212679,
        pc_saft_cp_ig_dippr_c0 = 1.21148319,
        pc_saft_cp_ig_dippr_c1 = 4.088175553,
        pc_saft_cp_ig_dippr_c2 = 1694.6,
        pc_saft_cp_ig_dippr_c3 = 2.749045667,
        pc_saft_cp_ig_dippr_c4 = 761.6,
        pc_saft_cp_ig_dippr_c5 = 200,
        pc_saft_cp_ig_dippr_c6 = 1500),
        
      ApiFluidStandardComponent(name="Ethylene", is_alkane=True, molar_mass=28.05316,         
        acentric_factor = 0.087,
        critical_pressure = 50.41,
        critical_temperature = 282.34,
        pc_saftdm = 0.0567914,
        pc_saft_sigma_0 = 3.445,
        pc_saft_epsilon = 176.47,
        ideal_gas_enthalpy_of_formation = 1871.80339,
        pc_saft_cp_ig_dippr_c0 = 1.189883778,
        pc_saft_cp_ig_dippr_c1 = 3.37894198,
        pc_saft_cp_ig_dippr_c2 = 1596,
        pc_saft_cp_ig_dippr_c3 = 1.964128105,
        pc_saft_cp_ig_dippr_c4 = 740.8,
        pc_saft_cp_ig_dippr_c5 = 60,
        pc_saft_cp_ig_dippr_c6 = 1500)
      ]

    fluid.polymers = [
        ApiFluidPolymerComponent(short_name="HDPE",
          blocks=[
            ApiFluidComponentBlock(block_massfraction=1, monomer_name="Ethylene", monomer_molar_mass=28.054, 
              pc_saftdm = 0.0263, 
              pc_saft_sigma_0 = 4.0217, 
              pc_saft_epsilon = 252.0,
              sle_c=0.4, 
              sle_hu=8220.0, 
              sle_density_amorphous=0.853, 
              sle_density_crystalline=1.004,
              ideal_gas_enthalpy_of_formation = -1613.2549,
              pc_saft_cp_ig_poly_c0 = 0.81694,
              pc_saft_cp_ig_poly_c1 = -0.00030569,
              pc_saft_cp_ig_poly_c2 = 0.000015706,
              pc_saft_cp_ig_poly_c3 = -2.1058E-08,
              pc_saft_cp_ig_poly_c4 = 8.5078E-12,
              pc_saft_cp_ig_poly_c5 = 0,
              pc_saft_cp_ig_poly_c6 = 200,
              pc_saft_cp_ig_poly_c7 = 1000)
      ],
          pseudo_components=[
            ApiFluidPseudoComponent(name= "HDPE(17.3)", melting_temperature = 415.82, molar_mass = 17300,  massfraction = 0.00498),
            ApiFluidPseudoComponent(name= "HDPE(25.6)", melting_temperature = 416.38, molar_mass = 25600,  massfraction = 0.03067),
            ApiFluidPseudoComponent(name= "HDPE(36)",   melting_temperature = 416.72, molar_mass = 36000,  massfraction = 0.23902),
            ApiFluidPseudoComponent(name= "HDPE(50)",   melting_temperature = 416.95, molar_mass = 50000,  massfraction = 0.45515),
            ApiFluidPseudoComponent(name= "HDPE(69.2)", melting_temperature = 417.12, molar_mass = 69200,  massfraction = 0.23902),
            ApiFluidPseudoComponent(name= "HDPE(97.6)", melting_temperature = 417.24, molar_mass = 97600,  massfraction = 0.03067),
            ApiFluidPseudoComponent(name= "HDPE(144)",  melting_temperature = 417.34, molar_mass = 144000, massfraction = 0.0005)                                 ]                            
        )
      ]
    
    fluid.kij = [
      ApiFluidKij(index_i=0, index_j=1, kija=0.0001),
      ApiFluidKij(index_i=0, index_j=2, kija=0.0002),
      ApiFluidKij(index_i=1, index_j=2, kija=0.0003),
      ]

    return fluid



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_output_calculation_result_point import ApiOutputCalculationResultPoint
from ..models.api_profile_information import ApiProfileInformation
from ..models.exception_info import ExceptionInfo
from ..types import UNSET, Unset

T = TypeVar("T", bound="BatchFlashCalculationResult")


@attr.s(auto_attribs=True)
class BatchFlashCalculationResult:
    """Holds calculation result for a point"""

    success: Union[Unset, bool] = UNSET
    calculation_id: Union[Unset, None, str] = UNSET
    exception_info: Union[Unset, ExceptionInfo] = UNSET
    profiling: Union[Unset, ApiProfileInformation] = UNSET
    points: List[ApiOutputCalculationResultPoint] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        success = self.success
        calculation_id = self.calculation_id
        exception_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.exception_info, Unset):
            exception_info = self.exception_info.to_dict()

        profiling: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profiling, Unset):
            profiling = self.profiling.to_dict()

        points = []
        for item_data in self.points:
            item = item_data.to_dict()
            points.append(item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if success is not UNSET:
            field_dict["success"] = success
        if calculation_id is not UNSET:
            field_dict["calculationId"] = calculation_id
        if exception_info is not UNSET:
            field_dict["exceptionInfo"] = exception_info
        if profiling is not UNSET:
            field_dict["profiling"] = profiling
        if points is not UNSET:
            field_dict["points"] = points

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        success = d.pop("success", UNSET)

        calculation_id = d.pop("calculationId", UNSET)

        _exception_info = d.pop("exceptionInfo", UNSET)
        exception_info: Union[Unset, ExceptionInfo]
        if isinstance(_exception_info, Unset):
            exception_info = UNSET
        else:
            exception_info = ExceptionInfo.from_dict(_exception_info)

        _profiling = d.pop("profiling", UNSET)
        profiling: Union[Unset, ApiProfileInformation]
        if isinstance(_profiling, Unset):
            profiling = UNSET
        else:
            profiling = ApiProfileInformation.from_dict(_profiling)

        points = []
        _points = d.pop("points")
        for item_data in _points:
            item = ApiOutputCalculationResultPoint.from_dict(item_data)
            points.append(item)

        batchflash_calculation_result = cls(
            success=success,
            calculation_id=calculation_id,
            exception_info=exception_info,
            profiling=profiling,
            points=points,
        )

        return batchflash_calculation_result



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_profile_time_information import ApiProfileTimeInformation
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiProfileInformation")


@attr.s(auto_attribs=True)
class ApiProfileInformation:
    """Holds profiling result"""

    profile_results: Union[Unset, None, List[ApiProfileTimeInformation]] = UNSET
    total_milli_seconds: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        profile_results: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.profile_results, Unset):
            if self.profile_results is None:
                profile_results = None
            else:
                profile_results = []
                for profile_results_item_data in self.profile_results:
                    profile_results_item = profile_results_item_data.to_dict()

                    profile_results.append(profile_results_item)

        total_milli_seconds = self.total_milli_seconds

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if profile_results is not UNSET:
            field_dict["profileResults"] = profile_results
        if total_milli_seconds is not UNSET:
            field_dict["totalMilliSeconds"] = total_milli_seconds

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        profile_results = []
        _profile_results = d.pop("profileResults", UNSET)
        for profile_results_item_data in _profile_results or []:
            profile_results_item = ApiProfileTimeInformation.from_dict(profile_results_item_data)

            profile_results.append(profile_results_item)

        total_milli_seconds = d.pop("totalMilliSeconds", UNSET)

        api_profile_information = cls(
            profile_results=profile_results,
            total_milli_seconds=total_milli_seconds,
        )

        return api_profile_information



from pickle import NONE
import pytest
from equia.models import CalculationComposition, ProblemDetails 
from equia.equia_client import EquiaClient
from utility.shared_settings import sharedsettings

@pytest.mark.asyncio
async def test_call_status():
    client = EquiaClient(sharedsettings.url, sharedsettings.access_key)

    input = client.get_status_input()

    result: ProblemDetails = await client.call_status_get_async(input)

    await client.cleanup()

    #assert result.status == 400
    assert result.success == True



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_value_floating_with_out_units_name import ApiValueFloatingWithOutUnitsName
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiValueComponentComposition")


@attr.s(auto_attribs=True)
class ApiValueComponentComposition:
    """Holds compositioninfo"""

    name: Union[Unset, None, str] = UNSET
    value: Union[Unset, float] = UNSET
    distribution: Union[Unset, None, List[ApiValueFloatingWithOutUnitsName]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        value = self.value
        distribution: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.distribution, Unset):
            if self.distribution is None:
                distribution = None
            else:
                distribution = []
                for distribution_item_data in self.distribution:
                    distribution_item = distribution_item_data.to_dict()

                    distribution.append(distribution_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if value is not UNSET:
            field_dict["value"] = value
        if distribution is not UNSET:
            field_dict["distribution"] = distribution

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        value = d.pop("value", UNSET)

        distribution = []
        _distribution = d.pop("distribution", UNSET)
        for distribution_item_data in _distribution or []:
            distribution_item = ApiValueFloatingWithOutUnitsName.from_dict(distribution_item_data)

            distribution.append(distribution_item)

        api_value_component_composition = cls(
            name=name,
            value=value,
            distribution=distribution,
        )

        return api_value_component_composition



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_output_phasediagram_point import ApiOutputPhasediagramPoint
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputPhasediagram")


@attr.s(auto_attribs=True)
class ApiOutputPhasediagram:
    """Result for a point"""

    temperature_units: Union[Unset, None, str] = UNSET
    pressure_units: Union[Unset, None, str] = UNSET
    phaseenvelope: Union[Unset, None, List[ApiOutputPhasediagramPoint]] = UNSET
    vlle: Union[Unset, None, List[ApiOutputPhasediagramPoint]] = UNSET
    sle: Union[Unset, None, List[ApiOutputPhasediagramPoint]] = UNSET
    spinodal: Union[Unset, None, List[ApiOutputPhasediagramPoint]] = UNSET
    slve: Union[Unset, None, List[ApiOutputPhasediagramPoint]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        temperature_units = self.temperature_units
        pressure_units = self.pressure_units
        phaseenvelope: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.phaseenvelope, Unset):
            if self.phaseenvelope is None:
                phaseenvelope = None
            else:
                phaseenvelope = []
                for phaseenvelope_item_data in self.phaseenvelope:
                    phaseenvelope_item = phaseenvelope_item_data.to_dict()

                    phaseenvelope.append(phaseenvelope_item)

        vlle: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.vlle, Unset):
            if self.vlle is None:
                vlle = None
            else:
                vlle = []
                for vlle_item_data in self.vlle:
                    vlle_item = vlle_item_data.to_dict()

                    vlle.append(vlle_item)

        sle: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sle, Unset):
            if self.sle is None:
                sle = None
            else:
                sle = []
                for sle_item_data in self.sle:
                    sle_item = sle_item_data.to_dict()

                    sle.append(sle_item)

        spinodal: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.spinodal, Unset):
            if self.spinodal is None:
                spinodal = None
            else:
                spinodal = []
                for spinodal_item_data in self.spinodal:
                    spinodal_item = spinodal_item_data.to_dict()

                    spinodal.append(spinodal_item)

        slve: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.slve, Unset):
            if self.slve is None:
                slve = None
            else:
                slve = []
                for slve_item_data in self.slve:
                    slve_item = slve_item_data.to_dict()

                    slve.append(slve_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if temperature_units is not UNSET:
            field_dict["temperatureUnits"] = temperature_units
        if pressure_units is not UNSET:
            field_dict["pressureUnits"] = pressure_units
        if phaseenvelope is not UNSET:
            field_dict["phaseenvelope"] = phaseenvelope
        if vlle is not UNSET:
            field_dict["vlle"] = vlle
        if sle is not UNSET:
            field_dict["sle"] = sle
        if spinodal is not UNSET:
            field_dict["spinodal"] = spinodal
        if slve is not UNSET:
            field_dict["slve"] = slve

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        temperature_units = d.pop("temperatureUnits", UNSET)

        pressure_units = d.pop("pressureUnits", UNSET)

        phaseenvelope = []
        _phaseenvelope = d.pop("phaseenvelope", UNSET)
        for phaseenvelope_item_data in _phaseenvelope or []:
            phaseenvelope_item = ApiOutputPhasediagramPoint.from_dict(phaseenvelope_item_data)

            phaseenvelope.append(phaseenvelope_item)

        vlle = []
        _vlle = d.pop("vlle", UNSET)
        for vlle_item_data in _vlle or []:
            vlle_item = ApiOutputPhasediagramPoint.from_dict(vlle_item_data)

            vlle.append(vlle_item)

        sle = []
        _sle = d.pop("sle", UNSET)
        for sle_item_data in _sle or []:
            sle_item = ApiOutputPhasediagramPoint.from_dict(sle_item_data)

            sle.append(sle_item)

        spinodal = []
        _spinodal = d.pop("spinodal", UNSET)
        for spinodal_item_data in _spinodal or []:
            spinodal_item = ApiOutputPhasediagramPoint.from_dict(spinodal_item_data)

            spinodal.append(spinodal_item)

        slve = []
        _slve = d.pop("slve", UNSET)
        for slve_item_data in _slve or []:
            slve_item = ApiOutputPhasediagramPoint.from_dict(slve_item_data)

            slve.append(slve_item)

        api_output_phasediagram = cls(
            temperature_units=temperature_units,
            pressure_units=pressure_units,
            phaseenvelope=phaseenvelope,
            vlle=vlle,
            sle=sle,
            spinodal=spinodal,
            slve=slve,
        )

        return api_output_phasediagram



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiFluidStandardComponent")


@attr.s(auto_attribs=True)
class ApiFluidStandardComponent:
    """Information for a fluid component"""

    formula: Union[Unset, None, str] = UNSET
    dippr_database_id: Union[Unset, int] = UNSET
    name: Union[Unset, None, str] = UNSET
    is_alkane: Union[Unset, bool] = UNSET
    sorting_order: Union[Unset, int] = UNSET
    molar_mass: Union[Unset, float] = UNSET
    critical_temperature: Union[Unset, float] = UNSET
    critical_pressure: Union[Unset, float] = UNSET
    critical_volume: Union[Unset, float] = UNSET
    acentric_factor: Union[Unset, float] = UNSET
    pc_saft_epsilon: Union[Unset, float] = UNSET
    pc_saft_sigma_0: Union[Unset, float] = UNSET
    pc_saft_sigma_1: Union[Unset, float] = UNSET
    pc_saft_sigma_2: Union[Unset, float] = UNSET
    pc_saft_sigma_3: Union[Unset, float] = UNSET
    pc_saft_sigma_4: Union[Unset, float] = UNSET
    pc_saftdm: Union[Unset, float] = UNSET
    pc_saft_ab_active: Union[Unset, bool] = UNSET
    pc_saft_ab_kappa: Union[Unset, float] = UNSET
    pc_saft_ab_epsilon: Union[Unset, float] = UNSET
    pc_saft_ab_scheme: Union[Unset, str] = UNSET
    pc_saft_polar_active: Union[Unset, bool] = UNSET
    pc_saft_polarx: Union[Unset, float] = UNSET
    pc_saft_polar_d: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c0: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c1: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c2: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c3: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c4: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c5: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c6: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c7: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c0: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c1: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c2: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c3: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c4: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c5: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c6: Union[Unset, float] = UNSET
    ideal_gas_enthalpy_of_formation: Union[Unset, float] = UNSET
    ideal_gas_gibbs_energy_of_formation: Union[Unset, float] = UNSET
    ideal_gas_absolute_entropy: Union[Unset, float] = UNSET
    standard_state_enthalpy_of_formation: Union[Unset, float] = UNSET
    standard_state_gibbs_energy_of_formation: Union[Unset, float] = UNSET
    standard_state_absolute_entropy: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        formula = self.formula
        dippr_database_id = self.dippr_database_id
        name = self.name
        is_alkane = self.is_alkane
        sorting_order = self.sorting_order
        molar_mass = self.molar_mass
        critical_temperature = self.critical_temperature
        critical_pressure = self.critical_pressure
        critical_volume = self.critical_volume
        acentric_factor = self.acentric_factor
        pc_saft_epsilon = self.pc_saft_epsilon
        pc_saft_sigma_0 = self.pc_saft_sigma_0
        pc_saft_sigma_1 = self.pc_saft_sigma_1
        pc_saft_sigma_2 = self.pc_saft_sigma_2
        pc_saft_sigma_3 = self.pc_saft_sigma_3
        pc_saft_sigma_4 = self.pc_saft_sigma_4
        pc_saftdm = self.pc_saftdm
        pc_saft_ab_active = self.pc_saft_ab_active
        pc_saft_ab_kappa = self.pc_saft_ab_kappa
        pc_saft_ab_epsilon = self.pc_saft_ab_epsilon
        pc_saft_ab_scheme = self.pc_saft_ab_scheme
        pc_saft_polar_active = self.pc_saft_polar_active
        pc_saft_polarx = self.pc_saft_polarx
        pc_saft_polar_d = self.pc_saft_polar_d
        pc_saft_cp_ig_poly_c0 = self.pc_saft_cp_ig_poly_c0
        pc_saft_cp_ig_poly_c1 = self.pc_saft_cp_ig_poly_c1
        pc_saft_cp_ig_poly_c2 = self.pc_saft_cp_ig_poly_c2
        pc_saft_cp_ig_poly_c3 = self.pc_saft_cp_ig_poly_c3
        pc_saft_cp_ig_poly_c4 = self.pc_saft_cp_ig_poly_c4
        pc_saft_cp_ig_poly_c5 = self.pc_saft_cp_ig_poly_c5
        pc_saft_cp_ig_poly_c6 = self.pc_saft_cp_ig_poly_c6
        pc_saft_cp_ig_poly_c7 = self.pc_saft_cp_ig_poly_c7
        pc_saft_cp_ig_dippr_c0 = self.pc_saft_cp_ig_dippr_c0
        pc_saft_cp_ig_dippr_c1 = self.pc_saft_cp_ig_dippr_c1
        pc_saft_cp_ig_dippr_c2 = self.pc_saft_cp_ig_dippr_c2
        pc_saft_cp_ig_dippr_c3 = self.pc_saft_cp_ig_dippr_c3
        pc_saft_cp_ig_dippr_c4 = self.pc_saft_cp_ig_dippr_c4
        pc_saft_cp_ig_dippr_c5 = self.pc_saft_cp_ig_dippr_c5
        pc_saft_cp_ig_dippr_c6 = self.pc_saft_cp_ig_dippr_c6
        ideal_gas_enthalpy_of_formation = self.ideal_gas_enthalpy_of_formation
        ideal_gas_gibbs_energy_of_formation = self.ideal_gas_gibbs_energy_of_formation
        ideal_gas_absolute_entropy = self.ideal_gas_absolute_entropy
        standard_state_enthalpy_of_formation = self.standard_state_enthalpy_of_formation
        standard_state_gibbs_energy_of_formation = self.standard_state_gibbs_energy_of_formation
        standard_state_absolute_entropy = self.standard_state_absolute_entropy

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if formula is not UNSET:
            field_dict["formula"] = formula
        if dippr_database_id is not UNSET:
            field_dict["dipprDatabaseId"] = dippr_database_id
        if name is not UNSET:
            field_dict["name"] = name
        if is_alkane is not UNSET:
            field_dict["isAlkane"] = is_alkane
        if sorting_order is not UNSET:
            field_dict["sortingOrder"] = sorting_order
        if molar_mass is not UNSET:
            field_dict["molarMass"] = molar_mass
        if critical_temperature is not UNSET:
            field_dict["criticalTemperature"] = critical_temperature
        if critical_pressure is not UNSET:
            field_dict["criticalPressure"] = critical_pressure
        if critical_volume is not UNSET:
            field_dict["criticalVolume"] = critical_volume
        if acentric_factor is not UNSET:
            field_dict["AcentricFactor"] = acentric_factor
        if pc_saft_epsilon is not UNSET:
            field_dict["pcSaftEpsilon"] = pc_saft_epsilon
        if pc_saft_sigma_0 is not UNSET:
            field_dict["pcSaftSigma0"] = pc_saft_sigma_0
        if pc_saft_sigma_1 is not UNSET:
            field_dict["pcSaftSigma1"] = pc_saft_sigma_1
        if pc_saft_sigma_2 is not UNSET:
            field_dict["pcSaftSigma2"] = pc_saft_sigma_2
        if pc_saft_sigma_3 is not UNSET:
            field_dict["pcSaftSigma3"] = pc_saft_sigma_3
        if pc_saft_sigma_4 is not UNSET:
            field_dict["pcSaftSigma4"] = pc_saft_sigma_4
        if pc_saftdm is not UNSET:
            field_dict["pcSaftdm"] = pc_saftdm
        if pc_saft_ab_active is not UNSET:
            field_dict["pcSaftAbActive"] = pc_saft_ab_active
        if pc_saft_ab_kappa is not UNSET:
            field_dict["pcSaftAbKappa"] = pc_saft_ab_kappa
        if pc_saft_ab_epsilon is not UNSET:
            field_dict["pcSaftAbEpsilon"] = pc_saft_ab_epsilon
        if pc_saft_ab_scheme is not UNSET:
            field_dict["pcSaftAbScheme"] = pc_saft_ab_scheme
        if pc_saft_polar_active is not UNSET:
            field_dict["pcSaftPolarActive"] = pc_saft_polar_active
        if pc_saft_polarx is not UNSET:
            field_dict["pcSaftPolarx"] = pc_saft_polarx
        if pc_saft_polar_d is not UNSET:
            field_dict["pcSaftPolarD"] = pc_saft_polar_d
        if pc_saft_cp_ig_poly_c0 is not UNSET:
            field_dict["pcSaftCpIgPolyC0"] = pc_saft_cp_ig_poly_c0
        if pc_saft_cp_ig_poly_c1 is not UNSET:
            field_dict["pcSaftCpIgPolyC1"] = pc_saft_cp_ig_poly_c1
        if pc_saft_cp_ig_poly_c2 is not UNSET:
            field_dict["pcSaftCpIgPolyC2"] = pc_saft_cp_ig_poly_c2
        if pc_saft_cp_ig_poly_c3 is not UNSET:
            field_dict["pcSaftCpIgPolyC3"] = pc_saft_cp_ig_poly_c3
        if pc_saft_cp_ig_poly_c4 is not UNSET:
            field_dict["pcSaftCpIgPolyC4"] = pc_saft_cp_ig_poly_c4
        if pc_saft_cp_ig_poly_c5 is not UNSET:
            field_dict["pcSaftCpIgPolyC5"] = pc_saft_cp_ig_poly_c5
        if pc_saft_cp_ig_poly_c6 is not UNSET:
            field_dict["pcSaftCpIgPolyC6"] = pc_saft_cp_ig_poly_c6
        if pc_saft_cp_ig_poly_c7 is not UNSET:
            field_dict["pcSaftCpIgPolyC7"] = pc_saft_cp_ig_poly_c7
        if pc_saft_cp_ig_dippr_c0 is not UNSET:
            field_dict["pcSaftCpIgDipprC0"] = pc_saft_cp_ig_dippr_c0
        if pc_saft_cp_ig_dippr_c1 is not UNSET:
            field_dict["pcSaftCpIgDipprC1"] = pc_saft_cp_ig_dippr_c1
        if pc_saft_cp_ig_dippr_c2 is not UNSET:
            field_dict["pcSaftCpIgDipprC2"] = pc_saft_cp_ig_dippr_c2
        if pc_saft_cp_ig_dippr_c3 is not UNSET:
            field_dict["pcSaftCpIgDipprC3"] = pc_saft_cp_ig_dippr_c3
        if pc_saft_cp_ig_dippr_c4 is not UNSET:
            field_dict["pcSaftCpIgDipprC4"] = pc_saft_cp_ig_dippr_c4
        if pc_saft_cp_ig_dippr_c5 is not UNSET:
            field_dict["pcSaftCpIgDipprC5"] = pc_saft_cp_ig_dippr_c5
        if pc_saft_cp_ig_dippr_c6 is not UNSET:
            field_dict["pcSaftCpIgDipprC6"] = pc_saft_cp_ig_dippr_c6
        if ideal_gas_enthalpy_of_formation is not UNSET:
            field_dict["idealGasEnthalpyOfFormation"] = ideal_gas_enthalpy_of_formation
        if ideal_gas_gibbs_energy_of_formation is not UNSET:
            field_dict["idealGasGibbsEnergyOfFormation"] = ideal_gas_gibbs_energy_of_formation
        if ideal_gas_absolute_entropy is not UNSET:
            field_dict["idealGasAbsoluteEntropy"] = ideal_gas_absolute_entropy
        if standard_state_enthalpy_of_formation is not UNSET:
            field_dict["standardStateEnthalpyOfFormation"] = standard_state_enthalpy_of_formation
        if standard_state_gibbs_energy_of_formation is not UNSET:
            field_dict["standardStateGibbsEnergyOfFormation"] = standard_state_gibbs_energy_of_formation
        if standard_state_absolute_entropy is not UNSET:
            field_dict["standardStateAbsoluteEntropy"] = standard_state_absolute_entropy

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        formula = d.pop("formula", UNSET)

        dippr_database_id = d.pop("dipprDatabaseId", UNSET)

        name = d.pop("name", UNSET)

        is_alkane = d.pop("isAlkane", UNSET)

        sorting_order = d.pop("sortingOrder", UNSET)

        molar_mass = d.pop("molarMass", UNSET)

        critical_temperature = d.pop("criticalTemperature", UNSET)

        critical_pressure = d.pop("criticalPressure", UNSET)

        critical_volume = d.pop("criticalVolume", UNSET)

        acentric_factor = d.pop("AcentricFactor", UNSET)

        pc_saft_epsilon = d.pop("pcSaftEpsilon", UNSET)

        pc_saft_sigma_0 = d.pop("pcSaftSigma0", UNSET)

        pc_saft_sigma_1 = d.pop("pcSaftSigma1", UNSET)

        pc_saft_sigma_2 = d.pop("pcSaftSigma2", UNSET)

        pc_saft_sigma_3 = d.pop("pcSaftSigma3", UNSET)

        pc_saft_sigma_4 = d.pop("pcSaftSigma4", UNSET)

        pc_saftdm = d.pop("pcSaftdm", UNSET)

        pc_saft_ab_active = d.pop("pcSaftAbActive", UNSET)

        pc_saft_ab_kappa = d.pop("pcSaftAbKappa", UNSET)

        pc_saft_ab_epsilon = d.pop("pcSaftAbEpsilon", UNSET)

        pc_saft_ab_scheme = d.pop("pcSaftAbScheme", UNSET)

        pc_saft_polar_active = d.pop("pcSaftPolarActive", UNSET)

        pc_saft_polarx = d.pop("pcSaftPolarx", UNSET)

        pc_saft_polar_d = d.pop("pcSaftPolarD", UNSET)

        pc_saft_cp_ig_poly_c0 = d.pop("pcSaftCpIgPolyC0", UNSET)

        pc_saft_cp_ig_poly_c1 = d.pop("pcSaftCpIgPolyC1", UNSET)

        pc_saft_cp_ig_poly_c2 = d.pop("pcSaftCpIgPolyC2", UNSET)

        pc_saft_cp_ig_poly_c3 = d.pop("pcSaftCpIgPolyC3", UNSET)

        pc_saft_cp_ig_poly_c4 = d.pop("pcSaftCpIgPolyC4", UNSET)

        pc_saft_cp_ig_poly_c5 = d.pop("pcSaftCpIgPolyC5", UNSET)

        pc_saft_cp_ig_poly_c6 = d.pop("pcSaftCpIgPolyC6", UNSET)

        pc_saft_cp_ig_poly_c7 = d.pop("pcSaftCpIgPolyC7", UNSET)

        pc_saft_cp_ig_dippr_c0 = d.pop("pcSaftCpIgDipprC0", UNSET)

        pc_saft_cp_ig_dippr_c1 = d.pop("pcSaftCpIgDipprC1", UNSET)

        pc_saft_cp_ig_dippr_c2 = d.pop("pcSaftCpIgDipprC2", UNSET)

        pc_saft_cp_ig_dippr_c3 = d.pop("pcSaftCpIgDipprC3", UNSET)

        pc_saft_cp_ig_dippr_c4 = d.pop("pcSaftCpIgDipprC4", UNSET)

        pc_saft_cp_ig_dippr_c5 = d.pop("pcSaftCpIgDipprC5", UNSET)

        pc_saft_cp_ig_dippr_c6 = d.pop("pcSaftCpIgDipprC6", UNSET)

        ideal_gas_enthalpy_of_formation = d.pop("idealGasEnthalpyOfFormation", UNSET)

        ideal_gas_gibbs_energy_of_formation = d.pop("idealGasGibbsEnergyOfFormation", UNSET)

        ideal_gas_absolute_entropy = d.pop("idealGasAbsoluteEntropy", UNSET)

        standard_state_enthalpy_of_formation = d.pop("standardStateEnthalpyOfFormation", UNSET)

        standard_state_gibbs_energy_of_formation = d.pop("standardStateGibbsEnergyOfFormation", UNSET)

        standard_state_absolute_entropy = d.pop("standardStateAbsoluteEntropy", UNSET)

        api_fluid_standard_component = cls(
            formula=formula,
            dippr_database_id=dippr_database_id,
            name=name,
            is_alkane=is_alkane,
            sorting_order=sorting_order,
            molar_mass=molar_mass,
            critical_temperature=critical_temperature,
            critical_pressure=critical_pressure,
            critical_volume=critical_volume,
            acentric_factor=acentric_factor,
            pc_saft_epsilon=pc_saft_epsilon,
            pc_saft_sigma_0=pc_saft_sigma_0,
            pc_saft_sigma_1=pc_saft_sigma_1,
            pc_saft_sigma_2=pc_saft_sigma_2,
            pc_saft_sigma_3=pc_saft_sigma_3,
            pc_saft_sigma_4=pc_saft_sigma_4,
            pc_saftdm=pc_saftdm,
            pc_saft_ab_active=pc_saft_ab_active,
            pc_saft_ab_kappa=pc_saft_ab_kappa,
            pc_saft_ab_epsilon=pc_saft_ab_epsilon,
            pc_saft_ab_scheme=pc_saft_ab_scheme,
            pc_saft_polar_active=pc_saft_polar_active,
            pc_saft_polarx=pc_saft_polarx,
            pc_saft_polar_d=pc_saft_polar_d,
            pc_saft_cp_ig_poly_c0=pc_saft_cp_ig_poly_c0,
            pc_saft_cp_ig_poly_c1=pc_saft_cp_ig_poly_c1,
            pc_saft_cp_ig_poly_c2=pc_saft_cp_ig_poly_c2,
            pc_saft_cp_ig_poly_c3=pc_saft_cp_ig_poly_c3,
            pc_saft_cp_ig_poly_c4=pc_saft_cp_ig_poly_c4,
            pc_saft_cp_ig_poly_c5=pc_saft_cp_ig_poly_c5,
            pc_saft_cp_ig_poly_c6=pc_saft_cp_ig_poly_c6,
            pc_saft_cp_ig_poly_c7=pc_saft_cp_ig_poly_c7,
            pc_saft_cp_ig_dippr_c0=pc_saft_cp_ig_dippr_c0,
            pc_saft_cp_ig_dippr_c1=pc_saft_cp_ig_dippr_c1,
            pc_saft_cp_ig_dippr_c2=pc_saft_cp_ig_dippr_c2,
            pc_saft_cp_ig_dippr_c3=pc_saft_cp_ig_dippr_c3,
            pc_saft_cp_ig_dippr_c4=pc_saft_cp_ig_dippr_c4,
            pc_saft_cp_ig_dippr_c5=pc_saft_cp_ig_dippr_c5,
            pc_saft_cp_ig_dippr_c6=pc_saft_cp_ig_dippr_c6,
            ideal_gas_enthalpy_of_formation=ideal_gas_enthalpy_of_formation,
            ideal_gas_gibbs_energy_of_formation=ideal_gas_gibbs_energy_of_formation,
            ideal_gas_absolute_entropy=ideal_gas_absolute_entropy,
            standard_state_enthalpy_of_formation=standard_state_enthalpy_of_formation,
            standard_state_gibbs_energy_of_formation=standard_state_gibbs_energy_of_formation,
            standard_state_absolute_entropy=standard_state_absolute_entropy,
        )

        return api_fluid_standard_component



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.api_fluid import ApiFluid
from ..types import UNSET, Unset

T = TypeVar("T", bound="FluidAddInput")


@attr.s(auto_attribs=True)
class FluidAddInput:
    """Input for added new fluid to database"""

    access_key: str
    fluid: Union[Unset, ApiFluid] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        access_key = self.access_key
        fluid: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fluid, Unset):
            fluid = self.fluid.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "accessKey": access_key,
            }
        )
        if fluid is not UNSET:
            field_dict["fluid"] = fluid

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        access_key = d.pop("accessKey")

        _fluid = d.pop("fluid", UNSET)
        fluid: Union[Unset, ApiFluid]
        if isinstance(_fluid, Unset):
            fluid = UNSET
        else:
            fluid = ApiFluid.from_dict(_fluid)

        new_fluid_input = cls(
            access_key=access_key,
            fluid=fluid,
        )

        return new_fluid_input



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiFluidComponentBlock")


@attr.s(auto_attribs=True)
class ApiFluidComponentBlock:
    """Values for a component block"""

    sorting_order: Union[Unset, int] = UNSET
    block_massfraction: Union[Unset, float] = UNSET
    block_name: Union[Unset, None, str] = UNSET
    monomer_name: Union[Unset, None, str] = UNSET
    monomer_molar_mass: Union[Unset, float] = UNSET
    pc_saft_epsilon: Union[Unset, float] = UNSET
    pc_saft_sigma_0: Union[Unset, float] = UNSET
    pc_saft_sigma_1: Union[Unset, float] = UNSET
    pc_saft_sigma_2: Union[Unset, float] = UNSET
    pc_saft_sigma_3: Union[Unset, float] = UNSET
    pc_saft_sigma_4: Union[Unset, float] = UNSET
    pc_saftdm: Union[Unset, float] = UNSET
    pc_saft_ab_active: Union[Unset, bool] = UNSET
    pc_saft_ab_kappa: Union[Unset, float] = UNSET
    pc_saft_ab_epsilon: Union[Unset, float] = UNSET
    pc_saft_ab_scheme: Union[Unset, str] = UNSET
    pc_saft_polar_active: Union[Unset, bool] = UNSET
    pc_saft_polarx: Union[Unset, float] = UNSET
    pc_saft_polar_d: Union[Unset, float] = UNSET
    sle_c: Union[Unset, float] = UNSET
    sle_hu: Union[Unset, float] = UNSET
    sle_density_amorphous: Union[Unset, float] = UNSET
    sle_density_crystalline: Union[Unset, float] = UNSET
    sle_tss: Union[Unset, float] = UNSET
    sle_hss: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c0: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c1: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c2: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c3: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c4: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c5: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c6: Union[Unset, float] = UNSET
    pc_saft_cp_ig_poly_c7: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c0: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c1: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c2: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c3: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c4: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c5: Union[Unset, float] = UNSET
    pc_saft_cp_ig_dippr_c6: Union[Unset, float] = UNSET
    ideal_gas_enthalpy_of_formation: Union[Unset, float] = UNSET
    ideal_gas_gibbs_energy_of_formation: Union[Unset, float] = UNSET
    ideal_gas_absolute_entropy: Union[Unset, float] = UNSET
    standard_state_enthalpy_of_formation: Union[Unset, float] = UNSET
    standard_state_gibbs_energy_of_formation: Union[Unset, float] = UNSET
    standard_state_absolute_entropy: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        sorting_order = self.sorting_order
        block_massfraction = self.block_massfraction
        block_name = self.block_name
        monomer_name = self.monomer_name
        monomer_molar_mass = self.monomer_molar_mass
        pc_saft_epsilon = self.pc_saft_epsilon
        pc_saft_sigma_0 = self.pc_saft_sigma_0
        pc_saft_sigma_1 = self.pc_saft_sigma_1
        pc_saft_sigma_2 = self.pc_saft_sigma_2
        pc_saft_sigma_3 = self.pc_saft_sigma_3
        pc_saft_sigma_4 = self.pc_saft_sigma_4
        pc_saftdm = self.pc_saftdm
        pc_saft_ab_active = self.pc_saft_ab_active
        pc_saft_ab_kappa = self.pc_saft_ab_kappa
        pc_saft_ab_epsilon = self.pc_saft_ab_epsilon
        pc_saft_ab_scheme = self.pc_saft_ab_scheme

        pc_saft_polar_active = self.pc_saft_polar_active
        pc_saft_polarx = self.pc_saft_polarx
        pc_saft_polar_d = self.pc_saft_polar_d
        sle_c = self.sle_c
        sle_hu = self.sle_hu
        sle_density_amorphous = self.sle_density_amorphous
        sle_density_crystalline = self.sle_density_crystalline
        sle_tss = self.sle_tss
        sle_hss = self.sle_hss
        pc_saft_cp_ig_poly_c0 = self.pc_saft_cp_ig_poly_c0
        pc_saft_cp_ig_poly_c1 = self.pc_saft_cp_ig_poly_c1
        pc_saft_cp_ig_poly_c2 = self.pc_saft_cp_ig_poly_c2
        pc_saft_cp_ig_poly_c3 = self.pc_saft_cp_ig_poly_c3
        pc_saft_cp_ig_poly_c4 = self.pc_saft_cp_ig_poly_c4
        pc_saft_cp_ig_poly_c5 = self.pc_saft_cp_ig_poly_c5
        pc_saft_cp_ig_poly_c6 = self.pc_saft_cp_ig_poly_c6
        pc_saft_cp_ig_poly_c7 = self.pc_saft_cp_ig_poly_c7
        pc_saft_cp_ig_dippr_c0 = self.pc_saft_cp_ig_dippr_c0
        pc_saft_cp_ig_dippr_c1 = self.pc_saft_cp_ig_dippr_c1
        pc_saft_cp_ig_dippr_c2 = self.pc_saft_cp_ig_dippr_c2
        pc_saft_cp_ig_dippr_c3 = self.pc_saft_cp_ig_dippr_c3
        pc_saft_cp_ig_dippr_c4 = self.pc_saft_cp_ig_dippr_c4
        pc_saft_cp_ig_dippr_c5 = self.pc_saft_cp_ig_dippr_c5
        pc_saft_cp_ig_dippr_c6 = self.pc_saft_cp_ig_dippr_c6
        ideal_gas_enthalpy_of_formation = self.ideal_gas_enthalpy_of_formation
        ideal_gas_gibbs_energy_of_formation = self.ideal_gas_gibbs_energy_of_formation
        ideal_gas_absolute_entropy = self.ideal_gas_absolute_entropy
        standard_state_enthalpy_of_formation = self.standard_state_enthalpy_of_formation
        standard_state_gibbs_energy_of_formation = self.standard_state_gibbs_energy_of_formation
        standard_state_absolute_entropy = self.standard_state_absolute_entropy

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if sorting_order is not UNSET:
            field_dict["sortingOrder"] = sorting_order
        if block_massfraction is not UNSET:
            field_dict["blockMassfraction"] = block_massfraction
        if block_name is not UNSET:
            field_dict["blockName"] = block_name
        if monomer_name is not UNSET:
            field_dict["monomerName"] = monomer_name
        if monomer_molar_mass is not UNSET:
            field_dict["monomerMolarMass"] = monomer_molar_mass
        if pc_saft_epsilon is not UNSET:
            field_dict["pcSaftEpsilon"] = pc_saft_epsilon
        if pc_saft_sigma_0 is not UNSET:
            field_dict["pcSaftSigma0"] = pc_saft_sigma_0
        if pc_saft_sigma_1 is not UNSET:
            field_dict["pcSaftSigma1"] = pc_saft_sigma_1
        if pc_saft_sigma_2 is not UNSET:
            field_dict["pcSaftSigma2"] = pc_saft_sigma_2
        if pc_saft_sigma_3 is not UNSET:
            field_dict["pcSaftSigma3"] = pc_saft_sigma_3
        if pc_saft_sigma_4 is not UNSET:
            field_dict["pcSaftSigma4"] = pc_saft_sigma_4
        if pc_saftdm is not UNSET:
            field_dict["pcSaftdm"] = pc_saftdm
        if pc_saft_ab_active is not UNSET:
            field_dict["pcSaftAbActive"] = pc_saft_ab_active
        if pc_saft_ab_kappa is not UNSET:
            field_dict["pcSaftAbKappa"] = pc_saft_ab_kappa
        if pc_saft_ab_epsilon is not UNSET:
            field_dict["pcSaftAbEpsilon"] = pc_saft_ab_epsilon
        if pc_saft_ab_scheme is not UNSET:
            field_dict["pcSaftAbScheme"] = pc_saft_ab_scheme
        if pc_saft_polar_active is not UNSET:
            field_dict["pcSaftPolarActive"] = pc_saft_polar_active
        if pc_saft_polarx is not UNSET:
            field_dict["pcSaftPolarx"] = pc_saft_polarx
        if pc_saft_polar_d is not UNSET:
            field_dict["pcSaftPolarD"] = pc_saft_polar_d
        if sle_c is not UNSET:
            field_dict["sleC"] = sle_c
        if sle_hu is not UNSET:
            field_dict["sleHu"] = sle_hu
        if sle_density_amorphous is not UNSET:
            field_dict["sleDensityAmorphous"] = sle_density_amorphous
        if sle_density_crystalline is not UNSET:
            field_dict["sleDensityCrystalline"] = sle_density_crystalline
        if sle_tss is not UNSET:
            field_dict["sleTss"] = sle_tss
        if sle_hss is not UNSET:
            field_dict["sleHss"] = sle_hss
        if pc_saft_cp_ig_poly_c0 is not UNSET:
            field_dict["pcSaftCpIgPolyC0"] = pc_saft_cp_ig_poly_c0
        if pc_saft_cp_ig_poly_c1 is not UNSET:
            field_dict["pcSaftCpIgPolyC1"] = pc_saft_cp_ig_poly_c1
        if pc_saft_cp_ig_poly_c2 is not UNSET:
            field_dict["pcSaftCpIgPolyC2"] = pc_saft_cp_ig_poly_c2
        if pc_saft_cp_ig_poly_c3 is not UNSET:
            field_dict["pcSaftCpIgPolyC3"] = pc_saft_cp_ig_poly_c3
        if pc_saft_cp_ig_poly_c4 is not UNSET:
            field_dict["pcSaftCpIgPolyC4"] = pc_saft_cp_ig_poly_c4
        if pc_saft_cp_ig_poly_c5 is not UNSET:
            field_dict["pcSaftCpIgPolyC5"] = pc_saft_cp_ig_poly_c5
        if pc_saft_cp_ig_poly_c6 is not UNSET:
            field_dict["pcSaftCpIgPolyC6"] = pc_saft_cp_ig_poly_c6
        if pc_saft_cp_ig_poly_c7 is not UNSET:
            field_dict["pcSaftCpIgPolyC7"] = pc_saft_cp_ig_poly_c7
        if pc_saft_cp_ig_dippr_c0 is not UNSET:
            field_dict["pcSaftCpIgDipprC0"] = pc_saft_cp_ig_dippr_c0
        if pc_saft_cp_ig_dippr_c1 is not UNSET:
            field_dict["pcSaftCpIgDipprC1"] = pc_saft_cp_ig_dippr_c1
        if pc_saft_cp_ig_dippr_c2 is not UNSET:
            field_dict["pcSaftCpIgDipprC2"] = pc_saft_cp_ig_dippr_c2
        if pc_saft_cp_ig_dippr_c3 is not UNSET:
            field_dict["pcSaftCpIgDipprC3"] = pc_saft_cp_ig_dippr_c3
        if pc_saft_cp_ig_dippr_c4 is not UNSET:
            field_dict["pcSaftCpIgDipprC4"] = pc_saft_cp_ig_dippr_c4
        if pc_saft_cp_ig_dippr_c5 is not UNSET:
            field_dict["pcSaftCpIgDipprC5"] = pc_saft_cp_ig_dippr_c5
        if pc_saft_cp_ig_dippr_c6 is not UNSET:
            field_dict["pcSaftCpIgDipprC6"] = pc_saft_cp_ig_dippr_c6
        if ideal_gas_enthalpy_of_formation is not UNSET:
            field_dict["idealGasEnthalpyOfFormation"] = ideal_gas_enthalpy_of_formation
        if ideal_gas_gibbs_energy_of_formation is not UNSET:
            field_dict["idealGasGibbsEnergyOfFormation"] = ideal_gas_gibbs_energy_of_formation
        if ideal_gas_absolute_entropy is not UNSET:
            field_dict["idealGasAbsoluteEntropy"] = ideal_gas_absolute_entropy
        if standard_state_enthalpy_of_formation is not UNSET:
            field_dict["standardStateEnthalpyOfFormation"] = standard_state_enthalpy_of_formation
        if standard_state_gibbs_energy_of_formation is not UNSET:
            field_dict["standardStateGibbsEnergyOfFormation"] = standard_state_gibbs_energy_of_formation
        if standard_state_absolute_entropy is not UNSET:
            field_dict["standardStateAbsoluteEntropy"] = standard_state_absolute_entropy

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        sorting_order = d.pop("sortingOrder", UNSET)

        block_massfraction = d.pop("blockMassfraction", UNSET)

        block_name = d.pop("blockName", UNSET)

        monomer_name = d.pop("monomerName", UNSET)

        monomer_molar_mass = d.pop("monomerMolarMass", UNSET)

        pc_saft_epsilon = d.pop("pcSaftEpsilon", UNSET)

        pc_saft_sigma_0 = d.pop("pcSaftSigma0", UNSET)

        pc_saft_sigma_1 = d.pop("pcSaftSigma1", UNSET)

        pc_saft_sigma_2 = d.pop("pcSaftSigma2", UNSET)

        pc_saft_sigma_3 = d.pop("pcSaftSigma3", UNSET)

        pc_saft_sigma_4 = d.pop("pcSaftSigma4", UNSET)

        pc_saftdm = d.pop("pcSaftdm", UNSET)

        pc_saft_ab_active = d.pop("pcSaftAbActive", UNSET)

        pc_saft_ab_kappa = d.pop("pcSaftAbKappa", UNSET)

        pc_saft_ab_epsilon = d.pop("pcSaftAbEpsilon", UNSET)

        pc_saft_ab_scheme = d.pop("pcSaftAbScheme", UNSET)

        pc_saft_polar_active = d.pop("pcSaftPolarActive", UNSET)

        pc_saft_polarx = d.pop("pcSaftPolarx", UNSET)

        pc_saft_polar_d = d.pop("pcSaftPolarD", UNSET)

        sle_c = d.pop("sleC", UNSET)

        sle_hu = d.pop("sleHu", UNSET)

        sle_density_amorphous = d.pop("sleDensityAmorphous", UNSET)

        sle_density_crystalline = d.pop("sleDensityCrystalline", UNSET)

        sle_tss = d.pop("sleTss", UNSET)

        sle_hss = d.pop("sleHss", UNSET)

        pc_saft_cp_ig_poly_c0 = d.pop("pcSaftCpIgPolyC0", UNSET)

        pc_saft_cp_ig_poly_c1 = d.pop("pcSaftCpIgPolyC1", UNSET)

        pc_saft_cp_ig_poly_c2 = d.pop("pcSaftCpIgPolyC2", UNSET)

        pc_saft_cp_ig_poly_c3 = d.pop("pcSaftCpIgPolyC3", UNSET)

        pc_saft_cp_ig_poly_c4 = d.pop("pcSaftCpIgPolyC4", UNSET)

        pc_saft_cp_ig_poly_c5 = d.pop("pcSaftCpIgPolyC5", UNSET)

        pc_saft_cp_ig_poly_c6 = d.pop("pcSaftCpIgPolyC6", UNSET)

        pc_saft_cp_ig_poly_c7 = d.pop("pcSaftCpIgPolyC7", UNSET)

        pc_saft_cp_ig_dippr_c0 = d.pop("pcSaftCpIgDipprC0", UNSET)

        pc_saft_cp_ig_dippr_c1 = d.pop("pcSaftCpIgDipprC1", UNSET)

        pc_saft_cp_ig_dippr_c2 = d.pop("pcSaftCpIgDipprC2", UNSET)

        pc_saft_cp_ig_dippr_c3 = d.pop("pcSaftCpIgDipprC3", UNSET)

        pc_saft_cp_ig_dippr_c4 = d.pop("pcSaftCpIgDipprC4", UNSET)

        pc_saft_cp_ig_dippr_c5 = d.pop("pcSaftCpIgDipprC5", UNSET)

        pc_saft_cp_ig_dippr_c6 = d.pop("pcSaftCpIgDipprC6", UNSET)

        ideal_gas_enthalpy_of_formation = d.pop("idealGasEnthalpyOfFormation", UNSET)

        ideal_gas_gibbs_energy_of_formation = d.pop("idealGasGibbsEnergyOfFormation", UNSET)

        ideal_gas_absolute_entropy = d.pop("idealGasAbsoluteEntropy", UNSET)

        standard_state_enthalpy_of_formation = d.pop("standardStateEnthalpyOfFormation", UNSET)

        standard_state_gibbs_energy_of_formation = d.pop("standardStateGibbsEnergyOfFormation", UNSET)

        standard_state_absolute_entropy = d.pop("standardStateAbsoluteEntropy", UNSET)

        api_fluid_component_block = cls(
            sorting_order=sorting_order,
            block_massfraction=block_massfraction,
            block_name=block_name,
            monomer_name=monomer_name,
            monomer_molar_mass=monomer_molar_mass,
            pc_saft_epsilon=pc_saft_epsilon,
            pc_saft_sigma_0=pc_saft_sigma_0,
            pc_saft_sigma_1=pc_saft_sigma_1,
            pc_saft_sigma_2=pc_saft_sigma_2,
            pc_saft_sigma_3=pc_saft_sigma_3,
            pc_saft_sigma_4=pc_saft_sigma_4,
            pc_saftdm=pc_saftdm,
            pc_saft_ab_active=pc_saft_ab_active,
            pc_saft_ab_kappa=pc_saft_ab_kappa,
            pc_saft_ab_epsilon=pc_saft_ab_epsilon,
            pc_saft_ab_scheme=pc_saft_ab_scheme,
            pc_saft_polar_active=pc_saft_polar_active,
            pc_saft_polarx=pc_saft_polarx,
            pc_saft_polar_d=pc_saft_polar_d,
            sle_c=sle_c,
            sle_hu=sle_hu,
            sle_density_amorphous=sle_density_amorphous,
            sle_density_crystalline=sle_density_crystalline,
            sle_tss=sle_tss,
            sle_hss=sle_hss,
            pc_saft_cp_ig_poly_c0=pc_saft_cp_ig_poly_c0,
            pc_saft_cp_ig_poly_c1=pc_saft_cp_ig_poly_c1,
            pc_saft_cp_ig_poly_c2=pc_saft_cp_ig_poly_c2,
            pc_saft_cp_ig_poly_c3=pc_saft_cp_ig_poly_c3,
            pc_saft_cp_ig_poly_c4=pc_saft_cp_ig_poly_c4,
            pc_saft_cp_ig_poly_c5=pc_saft_cp_ig_poly_c5,
            pc_saft_cp_ig_poly_c6=pc_saft_cp_ig_poly_c6,
            pc_saft_cp_ig_poly_c7=pc_saft_cp_ig_poly_c7,
            pc_saft_cp_ig_dippr_c0=pc_saft_cp_ig_dippr_c0,
            pc_saft_cp_ig_dippr_c1=pc_saft_cp_ig_dippr_c1,
            pc_saft_cp_ig_dippr_c2=pc_saft_cp_ig_dippr_c2,
            pc_saft_cp_ig_dippr_c3=pc_saft_cp_ig_dippr_c3,
            pc_saft_cp_ig_dippr_c4=pc_saft_cp_ig_dippr_c4,
            pc_saft_cp_ig_dippr_c5=pc_saft_cp_ig_dippr_c5,
            pc_saft_cp_ig_dippr_c6=pc_saft_cp_ig_dippr_c6,
            ideal_gas_enthalpy_of_formation=ideal_gas_enthalpy_of_formation,
            ideal_gas_gibbs_energy_of_formation=ideal_gas_gibbs_energy_of_formation,
            ideal_gas_absolute_entropy=ideal_gas_absolute_entropy,
            standard_state_enthalpy_of_formation=standard_state_enthalpy_of_formation,
            standard_state_gibbs_energy_of_formation=standard_state_gibbs_energy_of_formation,
            standard_state_absolute_entropy=standard_state_absolute_entropy,
        )

        return api_fluid_component_block



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.api_output_calculation_result_phase_composition import ApiOutputCalculationResultPhaseComposition
from ..models.api_output_calculation_result_phase_polymer_moments import ApiOutputCalculationResultPhasePolymerMoments
from ..models.api_value_compressibility import ApiValueCompressibility
from ..models.api_value_density import ApiValueDensity
from ..models.api_value_enthalpy import ApiValueEnthalpy
from ..models.api_value_entropy import ApiValueEntropy
from ..models.api_value_floating_with_units import ApiValueFloatingWithUnits
from ..models.api_value_mole_percent import ApiValueMolePercent
from ..models.api_value_volume import ApiValueVolume
from ..models.api_value_weight_percent import ApiValueWeightPercent
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiOutputCalculationResultPhase")


@attr.s(auto_attribs=True)
class ApiOutputCalculationResultPhase:
    """Holds all properties for a phase"""

    phase_type: Union[Unset, str] = UNSET
    phase_label: Union[Unset, None, str] = UNSET
    volume: Union[Unset, ApiValueVolume] = UNSET
    density: Union[Unset, ApiValueDensity] = UNSET
    entropy: Union[Unset, ApiValueEntropy] = UNSET
    enthalpy: Union[Unset, ApiValueEnthalpy] = UNSET
    cp: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    cv: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    jt_coefficient: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    speed_of_sound: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    solubility_parameter: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    molecular_weight: Union[Unset, ApiValueFloatingWithUnits] = UNSET
    compressibility: Union[Unset, ApiValueCompressibility] = UNSET
    mole_percent: Union[Unset, ApiValueMolePercent] = UNSET
    weight_percent: Union[Unset, ApiValueWeightPercent] = UNSET
    polymer_moments: Union[Unset,
                           ApiOutputCalculationResultPhasePolymerMoments] = UNSET
    composition: Union[Unset,
                       ApiOutputCalculationResultPhaseComposition] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        phase_type = self.phase_type
        phase_label = self.phase_label
        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        density: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.density, Unset):
            density = self.density.to_dict()

        entropy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.entropy, Unset):
            entropy = self.entropy.to_dict()

        enthalpy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.enthalpy, Unset):
            enthalpy = self.enthalpy.to_dict()

        cp: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.cp, Unset):
            cp = self.cp.to_dict()

        cv: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.cv, Unset):
            cv = self.cv.to_dict()

        jt_coefficient: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.jt_coefficient, Unset):
            jt_coefficient = self.jt_coefficient.to_dict()

        speed_of_sound: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.speed_of_sound, Unset):
            speed_of_sound = self.speed_of_sound.to_dict()

        solubility_parameter: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.solubility_parameter, Unset):
            solubility_parameter = self.solubility_parameter.to_dict()

        molecular_weight: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.molecular_weight, Unset):
            molecular_weight = self.molecular_weight.to_dict()

        compressibility: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.compressibility, Unset):
            compressibility = self.compressibility.to_dict()

        mole_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.mole_percent, Unset):
            mole_percent = self.mole_percent.to_dict()

        weight_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.weight_percent, Unset):
            weight_percent = self.weight_percent.to_dict()

        polymer_moments: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.polymer_moments, Unset):
            polymer_moments = self.polymer_moments.to_dict()

        composition: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.composition, Unset):
            composition = self.composition.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if phase_type is not UNSET:
            field_dict["phaseType"] = phase_type
        if phase_label is not UNSET:
            field_dict["phaseLabel"] = phase_label
        if volume is not UNSET:
            field_dict["volume"] = volume
        if density is not UNSET:
            field_dict["density"] = density
        if entropy is not UNSET:
            field_dict["entropy"] = entropy
        if enthalpy is not UNSET:
            field_dict["enthalpy"] = enthalpy
        if cp is not UNSET:
            field_dict["cp"] = cp
        if cv is not UNSET:
            field_dict["cv"] = cv
        if jt_coefficient is not UNSET:
            field_dict["jtcoefficient"] = jt_coefficient
        if speed_of_sound is not UNSET:
            field_dict["speedOfSound"] = speed_of_sound
        if solubility_parameter is not UNSET:
           field_dict["solubilityParameter"] = solubility_parameter
        if molecular_weight is not UNSET:
            field_dict["molecularWeight"] = molecular_weight
        if compressibility is not UNSET:
            field_dict["compressibility"] = compressibility
        if mole_percent is not UNSET:
            field_dict["molePercent"] = mole_percent
        if weight_percent is not UNSET:
            field_dict["weightPercent"] = weight_percent
        if polymer_moments is not UNSET:
            field_dict["polymerMoments"] = polymer_moments
        if composition is not UNSET:
            field_dict["composition"] = composition

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        phase_type = d.pop("phaseType", UNSET)

        phase_label = d.pop("phaseLabel", UNSET)

        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, ApiValueVolume]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = ApiValueVolume.from_dict(_volume)

        _density = d.pop("density", UNSET)
        density: Union[Unset, ApiValueDensity]
        if isinstance(_density, Unset):
            density = UNSET
        else:
            density = ApiValueDensity.from_dict(_density)

        _entropy = d.pop("entropy", UNSET)
        entropy: Union[Unset, ApiValueEntropy]
        if isinstance(_entropy, Unset):
            entropy = UNSET
        else:
            entropy = ApiValueEntropy.from_dict(_entropy)

        _enthalpy = d.pop("enthalpy", UNSET)
        enthalpy: Union[Unset, ApiValueEnthalpy]
        if isinstance(_enthalpy, Unset):
            enthalpy = UNSET
        else:
            enthalpy = ApiValueEnthalpy.from_dict(_enthalpy)

        _cp = d.pop("cp", UNSET)
        cp: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_cp, Unset):
            cp = UNSET
        else:
            cp = ApiValueFloatingWithUnits.from_dict(_cp)

        _cv = d.pop("cv", UNSET)
        cv: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_cv, Unset):
            cv = UNSET
        else:
            cv = ApiValueFloatingWithUnits.from_dict(_cv)

        _jt_coefficient = d.pop("jtCoefficient", UNSET)
        jt_coefficient: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_jt_coefficient, Unset):
            jt_coefficient = UNSET
        else:
            jt_coefficient = ApiValueFloatingWithUnits.from_dict(_jt_coefficient)

        _speed_of_sound = d.pop("speedOfSound", UNSET)
        speed_of_sound: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_speed_of_sound, Unset):
            speed_of_sound = UNSET
        else:
            speed_of_sound = ApiValueFloatingWithUnits.from_dict(
                _speed_of_sound)

        _solubility_parameter = d.pop("solubilityParameter", UNSET)
        solubility_parameter: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_solubility_parameter, Unset):
            solubility_parameter = UNSET
        else:
            solubility_parameter = ApiValueFloatingWithUnits.from_dict(_solubility_parameter)

        _molecular_weight = d.pop("molecularWeight", UNSET)
        molecular_weight: Union[Unset, ApiValueFloatingWithUnits]
        if isinstance(_molecular_weight, Unset):
            molecular_weight = UNSET
        else:
            molecular_weight = ApiValueFloatingWithUnits.from_dict(
                _molecular_weight)

        _compressibility = d.pop("compressibility", UNSET)
        compressibility: Union[Unset, ApiValueCompressibility]
        if isinstance(_compressibility, Unset):
            compressibility = UNSET
        else:
            compressibility = ApiValueCompressibility.from_dict(
                _compressibility)

        _mole_percent = d.pop("molePercent", UNSET)
        mole_percent: Union[Unset, ApiValueMolePercent]
        if isinstance(_mole_percent, Unset):
            mole_percent = UNSET
        else:
            mole_percent = ApiValueMolePercent.from_dict(_mole_percent)

        _weight_percent = d.pop("weightPercent", UNSET)
        weight_percent: Union[Unset, ApiValueWeightPercent]
        if isinstance(_weight_percent, Unset):
            weight_percent = UNSET
        else:
            weight_percent = ApiValueWeightPercent.from_dict(_weight_percent)

        _polymer_moments = d.pop("polymerMoments", UNSET)
        polymer_moments: Union[Unset,
                               ApiOutputCalculationResultPhasePolymerMoments]
        if isinstance(_polymer_moments, Unset):
            polymer_moments = UNSET
        else:
            polymer_moments = ApiOutputCalculationResultPhasePolymerMoments.from_dict(
                _polymer_moments)

        _composition = d.pop("composition", UNSET)
        composition: Union[Unset, ApiOutputCalculationResultPhaseComposition]
        if isinstance(_composition, Unset):
            composition = UNSET
        else:
            composition = ApiOutputCalculationResultPhaseComposition.from_dict(
                _composition)

        api_output_calculation_result_phase = cls(
            phase_type=phase_type,
            phase_label=phase_label,
            volume=volume,
            density=density,
            entropy=entropy,
            enthalpy=enthalpy,
            cp=cp,
            cv=cv,
            jt_coefficient=jt_coefficient,
            speed_of_sound=speed_of_sound,
            solubility_parameter=solubility_parameter,
            molecular_weight=molecular_weight,
            compressibility=compressibility,
            mole_percent=mole_percent,
            weight_percent=weight_percent,
            polymer_moments=polymer_moments,
            composition=composition,
        )

        return api_output_calculation_result_phase



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.api_fluid_component_block import ApiFluidComponentBlock
from ..models.api_fluid_pseudo_component import ApiFluidPseudoComponent
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiFluidPolymerComponent")


@attr.s(auto_attribs=True)
class ApiFluidPolymerComponent:
    """Information for a fluid component"""

    formula: Union[Unset, None, str] = UNSET
    short_name: Union[Unset, None, str] = UNSET
    sorting_order: Union[Unset, int] = UNSET
    pseudo_components: Union[Unset, None, List[ApiFluidPseudoComponent]] = UNSET
    blocks: Union[Unset, None, List[ApiFluidComponentBlock]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        formula = self.formula
        short_name = self.short_name
        sorting_order = self.sorting_order

        pseudo_components: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.pseudo_components, Unset):
            if self.pseudo_components is None:
                pseudo_components = None
            else:
                pseudo_components = []
                for pseudo_components_item_data in self.pseudo_components:
                    pseudo_components_item = pseudo_components_item_data.to_dict()

                    pseudo_components.append(pseudo_components_item)

        blocks: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.blocks, Unset):
            if self.blocks is None:
                blocks = None
            else:
                blocks = []
                for blocks_item_data in self.blocks:
                    blocks_item = blocks_item_data.to_dict()

                    blocks.append(blocks_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if formula is not UNSET:
            field_dict["formula"] = formula
        if short_name is not UNSET:
            field_dict["shortName"] = short_name
        if sorting_order is not UNSET:
            field_dict["sortingOrder"] = sorting_order
        if pseudo_components is not UNSET:
            field_dict["pseudoComponents"] = pseudo_components
        if blocks is not UNSET:
            field_dict["blocks"] = blocks

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        formula = d.pop("formula", UNSET)

        short_name = d.pop("shortName", UNSET)

        sorting_order = d.pop("sortingOrder", UNSET)

        pseudo_components = []
        _pseudo_components = d.pop("pseudoComponents", UNSET)
        for pseudo_components_item_data in _pseudo_components or []:
            pseudo_components_item = ApiFluidPseudoComponent.from_dict(pseudo_components_item_data)

            pseudo_components.append(pseudo_components_item)

        blocks = []
        _blocks = d.pop("blocks", UNSET)
        for blocks_item_data in _blocks or []:
            blocks_item = ApiFluidComponentBlock.from_dict(blocks_item_data)

            blocks.append(blocks_item)

        api_fluid_polymer_component = cls(
            formula=formula,
            short_name=short_name,
            sorting_order=sorting_order,
            pseudo_components=pseudo_components,
            blocks=blocks,
        )

        return api_fluid_polymer_component



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.calculation_composition import CalculationComposition
from ..models.api_fluid import ApiFluid
from ..types import UNSET, Unset

T = TypeVar("T", bound="BatchFlashCalculationItem")

@attr.s(auto_attribs=True)
class BatchFlashCalculationItem:
    """Item for batch flash calculation"""

    components: List[CalculationComposition] = UNSET # Component composition
    temperature: Union[Unset, float] = UNSET #Temperature in units given in 'Units' argument
    pressure: Union[Unset, float] = UNSET #Pressure in units given in 'Units' argument
    enthalpy: Union[Unset, float] = UNSET #Enthalpy in units given in 'Units' argument
    entropy: Union[Unset, float] = UNSET #Entropy in units given in 'Units' argument

    def to_dict(self) -> Dict[str, Any]:
        components = []
        for components_item_data in self.components:
            components_item = components_item_data.to_dict()
            components.append(components_item)

        temperature = self.temperature
        pressure = self.pressure
        enthalpy = self.enthalpy
        entropy = self.entropy

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "components": components,
            }
        )
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if pressure is not UNSET:
            field_dict["pressure"] = pressure
        if enthalpy is not UNSET:
            field_dict["enthalpy"] = enthalpy
        if entropy is not UNSET:
            field_dict["entropy"] = entropy

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        components = []
        _components = d.pop("components")
        for components_item_data in _components:
            components_item = CalculationComposition.from_dict(
                components_item_data)

            components.append(components_item)

        temperature = d.pop("temperature", UNSET)
        pressure = d.pop("pressure", UNSET)
        enthalpy = d.pop("enthalpy", UNSET)
        entropy = d.pop("entropy", UNSET)

        flash_calculation_input = cls(
            components=components,
            temperature=temperature,
            pressure=pressure,
            enthalpy=enthalpy,
            entropy=entropy,
        )

        return flash_calculation_input



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.batchflash_calculation_item import BatchFlashCalculationItem
from ..models.api_fluid import ApiFluid
from ..types import UNSET, Unset

T = TypeVar("T", bound="BatchFlashCalculationInput")

@attr.s(auto_attribs=True)
class BatchFlashCalculationInput:
    """Input for batch flash calculation"""

    access_key: str
    flashtype: str # Type of flash to perform. Allowed option: Fixed Temperature/Pressure, Fixed Pressure/Enthalpy or Fixed Pressure/Entropy
    units: str # Units used for input and output
    points: List[BatchFlashCalculationItem] # Flash pointts
    fluidid: Union[Unset, str] = UNSET #Id of fluid on webserver. Must be defined if no fluid given in fluid argument
    fluid: Union[Unset, ApiFluid] = UNSET #Fluid information

    def to_dict(self) -> Dict[str, Any]:
        access_key = self.access_key
        points = []
        for item_data in self.points:
            item = item_data.to_dict()
            points.append(item)

        flashtype = self.flashtype
        units = self.units

        fluidid: Union[Unset, str] = UNSET
        if not isinstance(self.fluidid, Unset):
            fluid = self.fluidid

        fluid: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fluid, Unset):
            fluid = self.fluid.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "accessKey": access_key,
                "points": points,
                "flashType": flashtype,
            }
        )
        if units is not UNSET:
            field_dict["units"] = units
        if fluidid is not UNSET:
            field_dict["fluidId"] = fluidid
        if fluid is not UNSET:
            field_dict["fluid"] = fluid

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        access_key = d.pop("accessKey")
        flashtype = d.pop("flashType")
        units = d.pop("units", UNSET)

        points = []
        _points = d.pop("points")
        for item_data in _points:
            item = BatchFlashCalculationItem.from_dict(item_data)
            points.append(item)

        _fluidid = d.pop("fluidId", UNSET)
        fluidid: Union[Unset, str]
        if isinstance(_fluidid, Unset):
            fluidid = UNSET
        else:
            fluidid = _fluidid

        _fluid = d.pop("fluid", UNSET)
        fluid: Union[Unset, ApiFluid]
        if isinstance(_fluid, Unset):
            fluid = UNSET
        else:
            fluid = ApiFluid.from_dict(_fluid)

        batchflash_calculation_input = cls(
            access_key=access_key,
            points=points,
            flashtype=flashtype,
            units=units,
            fluidid=fluidid,
            fluid=fluid,
        )

        return batchflash_calculation_input



from pickle import NONE
import pytest
from equia.models import ProblemDetails 
from equia.equia_client import EquiaClient
from equia.demofluids.demofluid1_nHexane_Ethylene_HDPE7 import demofluid1_nHexane_Ethylene_HDPE7
from utility.shared_settings import sharedsettings

@pytest.mark.asyncio
async def test_call_fluid():
#Add fluid
    clientAdd = EquiaClient(sharedsettings.url, sharedsettings.access_key)

    inputAdd = clientAdd.get_fluid_add_input()
    inputAdd.fluid = demofluid1_nHexane_Ethylene_HDPE7()

    resultAdd: ProblemDetails = await clientAdd.call_fluid_add_async(inputAdd)

    await clientAdd.cleanup()

    #assert result.status == 400
    assert resultAdd.success == True
#Get fluid    
    clientGet = EquiaClient(sharedsettings.url, sharedsettings.access_key)

    inputGet = clientGet.get_fluid_get_input()
    inputGet.fluidid = resultAdd.fluidid

    resultGet: ProblemDetails = await clientGet.call_fluid_get_async(inputGet)

    await clientGet.cleanup()

    #assert result.status == 400
    assert resultGet.success == True
    assert len(resultGet.fluid.standards) == 2
    assert len(resultGet.fluid.polymers) == 1

#Delete fluid
    clientDelete = EquiaClient(sharedsettings.url, sharedsettings.access_key)

    inputDelete = clientDelete.get_fluid_delete_input()
    inputDelete.fluidid = resultAdd.fluidid

    resultDelete: ProblemDetails = await clientDelete.call_fluid_delete_async(inputDelete)

    await clientDelete.cleanup()

    #assert result.status == 400
    assert resultDelete.success == True



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="FluidGetInput")


@attr.s(auto_attribs=True)
class FluidGetInput:
    """Input for request fluid information"""

    access_key: str
    fluidid: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        access_key = self.access_key
        fluidid = self.fluidid

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "accessKey": access_key,
            }
        )
        if fluidid is not UNSET:
            field_dict["fluidId"] = fluidid

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        access_key = d.pop("accessKey")

        fluidid = d.pop("fluidId", UNSET)

        request_fluid_input = cls(
            access_key=access_key,
            fluidid=fluidid,
        )

        return request_fluid_input



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.exception_info import ExceptionInfo
from ..types import UNSET, Unset

T = TypeVar("T", bound="FluidDeleteResult")


@attr.s(auto_attribs=True)
class FluidDeleteResult:
    """Holds result for deleting a fluid"""

    success: Union[Unset, bool] = UNSET
    exception_info: Union[Unset, ExceptionInfo] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        success = self.success

        exception_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.exception_info, Unset):
            exception_info = self.exception_info.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if success is not UNSET:
            field_dict["success"] = success
        if exception_info is not UNSET:
            field_dict["exceptionInfo"] = exception_info

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        success = d.pop("success", UNSET)

        _exception_info = d.pop("exceptionInfo", UNSET)
        exception_info: Union[Unset, ExceptionInfo]
        if isinstance(_exception_info, Unset):
            exception_info = UNSET
        else:
            exception_info = ExceptionInfo.from_dict(_exception_info)

        request_fluid_result = cls(
            success=success,
            exception_info=exception_info,
        )

        return request_fluid_result



import aiohttp
from typing import Any, Dict

from equia.models import StatusInput, StatusResult, CloudPointCalculationInput, CloudPointCalculationResult, \
    FlashCalculationInput, FlashCalculationResult, \
    BatchFlashCalculationInput, BatchFlashCalculationResult, \
    PhasediagramFixedTemperaturePressureCalculationInput, PhasediagramFixedTemperaturePressureCalculationResult, \
    FluidAddInput, FluidAddResult, FluidGetInput, FluidGetResult, FluidDeleteInput, FluidDeleteResult, \
    SlePointCalculationInput, SlePointCalculationResult, \
    EosPropertiesTPnCalculationInput, EosPropertiesTPnCalculationResult, \
    ProblemDetails \

class EquiaClient:
    """Class for making the calling to Equia API easy"""

    def __init__(self, base_url, access_key):
        self.__base_url = "{}/publicapi/01/".format(base_url)
        self.__access_key = access_key
        self.__session = aiohttp.ClientSession(
            connector=aiohttp.TCPConnector(ssl=False))

    async def cleanup(self):
        """Close session"""
        await self.__session.close()

    def __append_body(self, body: Dict[str, Any]) -> Dict[str, Any]:
        """Method that appends access_key to the body of the request"""
        user = {
            "accesskey": self.__access_key,
        }
        return {**body, **user}

    async def __post_async(self, endpoint: str, json_body: Dict[str, Any], from_dict):
        """Prepare the URL and the body and makes the POST request to the API"""
        url = "{}{endpoint}".format(self.__base_url, endpoint=endpoint)
        json_body = self.__append_body(json_body)
        try:
            async with self.__session.post(url, json=json_body) as resp:
                response = await resp.json()
                if resp.status == 200:
                    return from_dict(response)
                else:
                    return ProblemDetails.from_dict(response)
        except aiohttp.ClientConnectorError as e:
            print('Connection Error', str(e))
            return ProblemDetails.from_dict(e)

    async def call_status_get_async(
        self,
        body: StatusInput,
    ): 
      """Return fluid with givne id"""  
      return await self.__post_async("Status/GetStatus", body.to_dict(), StatusResult.from_dict)

    async def call_fluid_get_async(
        self,
        body: FluidGetInput,
    ): 
      """Return fluid with givne id"""  
      return await self.__post_async("Fluids/GetFluid", body.to_dict(), FluidGetResult.from_dict)

    async def call_fluid_add_async(
        self,
        body: FluidAddInput,
    ): 
      """Add given fluid to web server and return fluid id"""  
      return await self.__post_async("Fluids/AddFluid", body.to_dict(), FluidAddResult.from_dict)

    async def call_fluid_delete_async(
        self,
        body: FluidDeleteInput,
    ): 
      """Delete given fluid on the web server"""  
      return await self.__post_async("Fluids/DeleteFluid", body.to_dict(), FluidDeleteResult.from_dict)

    async def call_flash_async(
        self,
        body: FlashCalculationInput,
    ):
        """Perform flash calculation"""
        return await self.__post_async("Calculations/Flash", body.to_dict(), FlashCalculationResult.from_dict)

    async def call_batchflash_async(
        self,
        body: BatchFlashCalculationInput,
    ):
        """Perform batch flash calculation"""
        return await self.__post_async("Calculations/BatchFlash", body.to_dict(), BatchFlashCalculationResult.from_dict)

    async def call_cloud_point_async(
        self,
        body: CloudPointCalculationInput,
    ):
        """Perform cloud point calculation"""
        return await self.__post_async("Calculations/CloudPoint", body.to_dict(), CloudPointCalculationResult.from_dict)

    async def call_sle_point_async(
        self,
        body: SlePointCalculationInput,
    ):
        """Perform SLE point calculation"""
        return await self.__post_async("Calculations/SlePoint", body.to_dict(), SlePointCalculationResult.from_dict)

    async def call_phasediagram_standard_async(
        self,
        body: PhasediagramFixedTemperaturePressureCalculationInput,
    ):
        """Perform Phasediagram standard calculation"""
        return await self.__post_async("Calculations/PhasediagramStandard", body.to_dict(), PhasediagramFixedTemperaturePressureCalculationResult.from_dict)

    async def call_eospropertiestpn_async(
        self,
        body: EosPropertiesTPnCalculationInput,
    ):
        """Perform Eos property TPn calculation"""
        return await self.__post_async("Properties/EosTPn", body.to_dict(), EosPropertiesTPnCalculationResult.from_dict)

    def get_status_input(self):
        """Returns status argument filled with standard input"""
        return StatusInput(access_key=self.__access_key)

    def get_flash_input(self):
        """Returns flash argument filled with standard input"""
        return FlashCalculationInput(access_key=self.__access_key, units=self.__get_units(), components=[], fluidid="", flashtype="Fixed Temperature/Pressure")

    def get_batchflash_input(self):
        """Returns batch flash argument filled with standard input"""
        return BatchFlashCalculationInput(access_key=self.__access_key, units=self.__get_units(), points=[], fluidid="", flashtype="Fixed Temperature/Pressure")

    def get_cloud_point_input(self):
        """Returns cloud point argument filled with standard input"""
        return CloudPointCalculationInput(access_key=self.__access_key, units=self.__get_units(), components=[], fluidid="", pointtype="Fixed Temperature")

    def get_eospropertiestpn_input(self):
        """Returns Eos property TPN argument filled with standard input"""
        return EosPropertiesTPnCalculationInput(access_key=self.__access_key, units=self.__get_units(), components=[], fluidid="", volumetype="Auto")

    def get_sle_point_input(self):
        """Returns SLE point argument filled with standard input"""
        return SlePointCalculationInput(access_key=self.__access_key, units=self.__get_units(), components=[], fluidid="", pointtype="Fixed Pressure")

    def get_phasediagam_standard_input(self):
        """Returns phase diagram standard argument filled with standard input"""
        return PhasediagramFixedTemperaturePressureCalculationInput(access_key=self.__access_key, units=self.__get_units(), components=[], fluidid="")

    def get_fluid_get_input(self):
        """Returns request fluid argument filled with standard input"""
        return FluidGetInput(access_key=self.__access_key)

    def get_fluid_add_input(self):
        """Returns new fluid argument filled with standard input"""
        return FluidAddInput(access_key=self.__access_key)

    def get_fluid_delete_input(self):
        """Returns new fluid argument filled with standard input"""
        return FluidDeleteInput(access_key=self.__access_key)

    def __get_units(self):
        return "C(In,Massfraction);C(Out,Massfraction);T(In,Kelvin);T(Out,Kelvin);P(In,Bar);P(Out,Bar);H(In,kJ/Kg);H(Out,kJ/Kg);S(In,kJ/(Kg Kelvin));S(Out,kJ/(Kg Kelvin));Cp(In,kJ/(Kg Kelvin));Cp(Out,kJ/(Kg Kelvin));Viscosity(In,centiPoise);Viscosity(Out,centiPoise);Surfacetension(In,N/m);Surfacetension(Out,N/m)"



""" Contains all the data models used in inputs/outputs """

from equia.models.api_fluid import ApiFluid
from equia.models.api_fluid_component_block import ApiFluidComponentBlock
from equia.models.api_fluid_kij import ApiFluidKij
from equia.models.api_fluid_polymer_component import ApiFluidPolymerComponent
from equia.models.api_fluid_pseudo_component import ApiFluidPseudoComponent
from equia.models.api_fluid_standard_component import ApiFluidStandardComponent
from equia.models.api_output_calculation_result_phase import ApiOutputCalculationResultPhase
from equia.models.api_output_calculation_result_phase_composition import ApiOutputCalculationResultPhaseComposition
from equia.models.api_output_calculation_result_phase_polymer_moment import ApiOutputCalculationResultPhasePolymerMoment
from equia.models.api_output_calculation_result_phase_polymer_moments import ApiOutputCalculationResultPhasePolymerMoments
from equia.models.api_output_calculation_result_point import ApiOutputCalculationResultPoint
from equia.models.api_output_phasediagram import ApiOutputPhasediagram
from equia.models.api_output_phasediagram_point import ApiOutputPhasediagramPoint
from equia.models.api_output_eospropertiestpn_result import ApiOutputEosProperetiesTPnResult
from equia.models.api_output_eospropertiestpn_ideal import ApiOutputEosProperetiesTPnResultIdeal
from equia.models.api_output_eospropertiestpn_residual import ApiOutputEosProperetiesTPnResultResidual
from equia.models.api_profile_information import ApiProfileInformation
from equia.models.api_profile_time_information import ApiProfileTimeInformation
from equia.models.api_value_floating_with_out_units import ApiValueFloatingWithOutUnits
from equia.models.api_value_floating_with_out_units_name import ApiValueFloatingWithOutUnitsName
from equia.models.api_value_floating_with_units import ApiValueFloatingWithUnits
from equia.models.api_value_component_composition import ApiValueComponentComposition
from equia.models.api_value_composition_array import ApiValueCompositionArray
from equia.models.api_value_compressibility import ApiValueCompressibility
from equia.models.api_value_density import ApiValueDensity
from equia.models.api_value_enthalpy import ApiValueEnthalpy
from equia.models.api_value_entropy import ApiValueEntropy
from equia.models.api_value_mole_percent import ApiValueMolePercent
from equia.models.api_value_pressure import ApiValuePressure
from equia.models.api_value_temperature import ApiValueTemperature
from equia.models.api_value_volume import ApiValueVolume
from equia.models.api_value_weight_percent import ApiValueWeightPercent
from equia.models.calculation_block_info import CalculationBlockInfo
from equia.models.calculation_composition import CalculationComposition
from equia.models.cloud_point_calculation_input import CloudPointCalculationInput
from equia.models.cloud_point_calculation_result import CloudPointCalculationResult
from equia.models.exception_info import ExceptionInfo
from equia.models.flash_calculation_input import FlashCalculationInput
from equia.models.flash_calculation_result import FlashCalculationResult
from equia.models.batchflash_calculation_input import BatchFlashCalculationInput
from equia.models.batchflash_calculation_result import BatchFlashCalculationResult
from equia.models.api_fluid_distribution_moment import ApiFluidDistributionMoment
from equia.models.fluid_add_input import FluidAddInput
from equia.models.fluid_add_result import FluidAddResult
from equia.models.fluid_delete_input import FluidDeleteInput
from equia.models.fluid_delete_result import FluidDeleteResult

from equia.models.status_input import StatusInput
from equia.models.status_result import StatusResult

from equia.models.phasediagram_fixed_temperature_pressure_calculation_input import (
    PhasediagramFixedTemperaturePressureCalculationInput,
)
from equia.models.phasediagram_fixed_temperature_pressure_calculation_result import (
    PhasediagramFixedTemperaturePressureCalculationResult,
)
from equia.models.problem_details import ProblemDetails
from equia.models.fluid_get_input import FluidGetInput
from equia.models.fluid_get_result import FluidGetResult
from equia.models.sle_point_calculation_input import SlePointCalculationInput
from equia.models.sle_point_calculation_result import SlePointCalculationResult
from equia.models.eospropertiestpn_calculation_input import EosPropertiesTPnCalculationInput
from equia.models.eospropertiestpn_calculation_result import EosPropertiesTPnCalculationResult



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiFluidDistributionMoment")


@attr.s(auto_attribs=True)
class ApiFluidDistributionMoment:
    """Distribution for a fluid component

    Input is used to generate a distribution for the polymer

    One or more of Mn, Mw, Mz must be given"""

    model: Union[Unset, str] = UNSET
    number_of_pseudo_components: Union[Unset, int] = UNSET
    mn: Union[Unset, float] = UNSET
    mw: Union[Unset, float] = UNSET
    mz: Union[Unset, float] = UNSET
    minimum_molar_mass: Union[Unset, float] = UNSET
    maximum_molar_mass: Union[Unset, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        model = self.model
        number_of_pseudo_components = self.number_of_pseudo_components
        mn = self.mn
        mw = self.mw
        mz = self.mz
        minimum_molar_mass = self.minimum_molar_mass
        maximum_molar_mass = self.maximum_molar_mass

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if model is not UNSET:
            field_dict["model"] = model
        if number_of_pseudo_components is not UNSET:
            field_dict["numberOfPseudoComponents"] = number_of_pseudo_components
        if mn is not UNSET:
            field_dict["mn"] = mn
        if mw is not UNSET:
            field_dict["mw"] = mw
        if mz is not UNSET:
            field_dict["mz"] = mz
        if minimum_molar_mass is not UNSET:
            field_dict["minimumMolarMass"] = minimum_molar_mass
        if maximum_molar_mass is not UNSET:
            field_dict["maximumMolarMass"] = maximum_molar_mass

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        model = d.pop("model", UNSET)

        number_of_pseudo_components = d.pop("numberOfPseudoComponents", UNSET)

        mn = d.pop("mn", UNSET)

        mw = d.pop("mw", UNSET)

        mz = d.pop("mz", UNSET)

        minimum_molar_mass = d.pop("minimumMolarMass", UNSET)

        maximum_molar_mass = d.pop("maximumMolarMass", UNSET)

        api_fluid_distribution_moment = cls(
            model=model,
            number_of_pseudo_components=number_of_pseudo_components,
            mn=mn,
            mw=mw,
            mz=mz,
            minimum_molar_mass=minimum_molar_mass,
            maximum_molar_mass=maximum_molar_mass,
        )

        return api_fluid_distribution_moment



import datetime
from typing import Any, Dict, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="ExceptionInfo")


@attr.s(auto_attribs=True)
class ExceptionInfo:
    """Contains information for unexpected errors"""

    message_type: Union[Unset, None, str] = UNSET
    message: Union[Unset, None, str] = UNSET
    stack_trace: Union[Unset, None, str] = UNSET
    date: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        message_type = self.message_type
        message = self.message
        stack_trace = self.stack_trace
        date: Union[Unset, str] = UNSET
        if not isinstance(self.date, Unset):
            date = self.date.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if message_type is not UNSET:
            field_dict["messageType"] = message_type
        if message is not UNSET:
            field_dict["message"] = message
        if stack_trace is not UNSET:
            field_dict["stackTrace"] = stack_trace
        if date is not UNSET:
            field_dict["date"] = date

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        message_type = d.pop("messageType", UNSET)

        message = d.pop("message", UNSET)

        stack_trace = d.pop("stackTrace", UNSET)

        _date = d.pop("date", UNSET)
        date: Union[Unset, datetime.datetime]
        if isinstance(_date, Unset):
            date = UNSET
        else:
            date = isoparse(_date)

        exception_info = cls(
            message_type=message_type,
            message=message,
            stack_trace=stack_trace,
            date=date,
        )

        return exception_info
